UrlUtils class
Constructors
- UrlUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- URL_AUTH → const String
- URL_CHANGE_EXPIRED_PASSWORD → const String
- URL_CHANGE_PASSWORD → const String
- URL_CURRENT_LOGIN_INFO → const String
- URL_FORGET_PASSWORD → const String
- URL_GET_ALL_DEFAULTS → const String
- URL_GET_ALL_USERS → const String
- URL_GET_LAYOUT_BY_ROLE_ID → const String
- URL_GET_MOBILE_VERSION → const String
- URL_GET_USER_ROLE → const String
- URL_IMPERSONATE → const String
- URL_IS_IMPERSONATOR → const String
- URL_REQUEST_FORGET_PASSWORD → const String
- URL_STORAGE → const String